summaryrefslogtreecommitdiff
path: root/src/du.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/du.c')
-rw-r--r--src/du.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/du.c b/src/du.c
index fa35569c2..8e88b5621 100644
--- a/src/du.c
+++ b/src/du.c
@@ -81,8 +81,8 @@ struct duinfo
/* Number of inodes in directory. */
uintmax_t inodes;
- /* Latest time stamp found. If tmax.tv_sec == TYPE_MINIMUM (time_t)
- && tmax.tv_nsec < 0, no time stamp has been found. */
+ /* Latest timestamp found. If tmax.tv_sec == TYPE_MINIMUM (time_t)
+ && tmax.tv_nsec < 0, no timestamp has been found. */
struct timespec tmax;
};
@@ -255,8 +255,8 @@ static enum time_type const time_types[] =
ARGMATCH_VERIFY (time_args, time_types);
/* 'full-iso' uses full ISO-style dates and times. 'long-iso' uses longer
- ISO-style time stamps, though shorter than 'full-iso'. 'iso' uses shorter
- ISO-style time stamps. */
+ ISO-style timestamps, though shorter than 'full-iso'. 'iso' uses shorter
+ ISO-style timestamps. */
enum time_style
{
full_iso_time_style, /* --time-style=full-iso */